==> gworkspace-0.8.2.tar.gz: GWorkspace-0.8.2/Recycler/RecyclerIcon.h <==
/* RecyclerIcon.h
 *  
 * Copyright (C) 2004 Free Software Foundation, Inc.
 *
 * Author: Enrico Sersale <enrico@imago.ro>
 * Date: June 2004
 *
 * This file is part of the GNUstep Recycler application
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */

#ifndef RECYCLER_ICON_H
#define RECYCLER_ICON_H

#include <AppKit/NSView.h>
#include "FSNIcon.h"

@class NSColor;
@class NSImage;
@class NSWorkspace;

@interface RecyclerIcon : FSNIcon
{
  NSImage *trashFullIcon;
  BOOL trashFull;
  NSWorkspace *ws;
}

- (id)initWithRecyclerNode:(FSNode *)anode;
 
- (void)setTrashFull:(BOOL)value;

@end


@interface RecyclerIcon (DraggingDestination)

- (unsigned int)draggingEntered:(id <NSDraggingInfo>)sender;

- (unsigned int)draggingUpdated:(id <NSDraggingInfo>)sender;

- (void)draggingExited:(id <NSDraggingInfo>)sender;

- (BOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender;

- (BOOL)performDragOperation:(id <NSDraggingInfo>)sender;

- (void)concludeDragOperation:(id <NSDraggingInfo>)sender;

@end

#endif // RECYCLER_ICON_H

==> gworkspace_0.8.3.orig.tar.gz: GWorkspace-0.8.3/Recycler/RecyclerIcon.h <==
/* RecyclerIcon.h
 *  
 * Copyright (C) 2004 Free Software Foundation, Inc.
 *
 * Author: Enrico Sersale <enrico@imago.ro>
 * Date: June 2004
 *
 * This file is part of the GNUstep Recycler application
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
 */

#ifndef RECYCLER_ICON_H
#define RECYCLER_ICON_H

#include <AppKit/NSView.h>
#include "FSNIcon.h"

@class NSColor;
@class NSImage;
@class NSWorkspace;

@interface RecyclerIcon : FSNIcon
{
  NSImage *trashFullIcon;
  BOOL trashFull;
  NSWorkspace *ws;
}

- (id)initWithRecyclerNode:(FSNode *)anode;
 
- (void)setTrashFull:(BOOL)value;

@end


@interface RecyclerIcon (DraggingDestination)

- (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender;

- (NSDragOperation)draggingUpdated:(id <NSDraggingInfo>)sender;

- (void)draggingExited:(id <NSDraggingInfo>)sender;

- (BOOL)prepareForDragOperation:(id <NSDraggingInfo>)sender;

- (BOOL)performDragOperation:(id <NSDraggingInfo>)sender;

- (void)concludeDragOperation:(id <NSDraggingInfo>)sender;

@end

#endif // RECYCLER_ICON_H
